// java wrapper for vtkGeoTerrain2D object
//

package vtk;
import vtk.*;

public class vtkGeoTerrain2D extends vtkGeoTerrain
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTextureTolerance_2(double id0);
  public void SetTextureTolerance(double id0)
    { SetTextureTolerance_2(id0); }

  private native double GetTextureTolerance_3();
  public double GetTextureTolerance()
    { return GetTextureTolerance_3(); }

  private native void SetLocationTolerance_4(double id0);
  public void SetLocationTolerance(double id0)
    { SetLocationTolerance_4(id0); }

  private native double GetLocationTolerance_5();
  public double GetLocationTolerance()
    { return GetLocationTolerance_5(); }

  private native long GetTransform_6();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_6();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGeoTerrain2D() { super(); }

  public vtkGeoTerrain2D(long id) { super(id); }
  public native long   VTKInit();

}
